==> nextcloud-app-spreed-5.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/hu.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "SSL tanúsítvány érvényesítése",
    "Delete server" : "Szerver törlése",
    "Add new server" : "Szerver hozzáadása",
    "Saved" : "Elmentve",
    "Shared secret" : "Megosztott titok",
    "TURN server shared secret" : "TURN szerver megosztott titok",
    "UDP and TCP" : "UDP és TCP",
    "UDP only" : "csak UDP",
    "TCP only" : "csak TCP",
    "TURN server protocols" : "TURN kiszolgáló protokollok",
    "New public conversation" : "Új nyilvános beszélgetés",
    "New group conversation" : "Új csoport beszélgetés",
    "New conversation …" : "Új beszélgetés …",
    "Participants" : "Résztvevők",
    "Chat" : "Csevegés",
    "Talk" : "Beszélgetés",
    "Exit fullscreen (f)" : "Kilépés a teljes képernyős módból (f)",
    "Fullscreen (f)" : "Teljes képernyő (f)",
    "Copy" : "Másol",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "Nyomj ⌘-C-t a másoláshoz.",
    "Press Ctrl-C to copy." : "Nyomj Ctrl-C-t a másoláshoz.",
    "Request password" : "Jelszó kérése",
    "Error requesting the password." : "Hiba a jelszó kérésekor.",
    "Please enter the password for this call" : "Kérlek adj meg egy jelszót ehhez a híváshoz",
    "Password required" : "Jelszó szükséges",
    "Password" : "Jelszó",
    "Cancel" : "Mégse",
    "Submit" : "Küldés",
    "Leave call" : "Hívás elhagyása",
    "Join call" : "Csatlakozás híváshoz",
    "Start call" : "Hívás indítása",
    "Share link" : "Megosztás hivatkozással",
    "Change password" : "Jelszó módosítása",
    "Set password" : "Jelszó beállítása",
    "Name" : "Név",
    "Conversation name" : "Beszélgetés neve",
    "Rename" : "Átnevezés",
    "Copy link" : "Hivatkozás másolása",
    "Conversation with {name}" : "Beszélgetés vele: {name}",
    "Error occurred while setting password" : "Hiba a jelszó beállításakor",
    "Link copied!" : "Hivatkozás másolva!",
    "You" : "Te",
    "No messages yet, start the conversation!" : "Még nincs üzenet, kezdeményezz beszélgetést!",
    "New message …" : "Új üzenet ...",
    "Send" : "Küld",
    "Guest" : "Vendég",
    "[Unknown user name]" : "[ismeretlen felhasználónév]",
    "Today" : "Ma",
    "Yesterday" : "Tegnap",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Hiba az üzenetküldés közben",
    "File to share" : "Fájl megosztása",
    "Error while sharing" : "Hiba megosztás közben",
    "Edit" : "Szerkesztés",
    "Join a conversation or start a new one" : "Csatlakozz egy társalgásba vagy indíts egy újat",
    "No other people in this call" : "Nincs más ebben a hívásban",
    "Waiting for {participantName} to join the call …" : "Várakozunk, hogy {participantName} csatlakozzon a híváshoz...",
    "Waiting for others to join the call …" : "Várakozunk, hogy mások csatlakozzanak a híváshoz...",
    "You can invite others in the participant tab of the sidebar" : "Az oldalsávon található „közreműködő” fülön lehet másokat meghívni",
    "Share this link to invite others!" : "Oszd meg ezt a linket mások meghívásához!",
    "WebRTC is not supported in your browser :-/" : "A böngésződ nem támogatja a WebRTC-t :-/",
    "Please use a different browser like Firefox or Chrome" : "Kérlek használj másik böngészőt pl Firefoxot vagy Chrome-ot",
    "Waiting for camera and microphone permissions" : "Várakozás kamera és mikrofon engedélyezésre",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Kérlek engedélyezd a kamera és mikrofon elérést az app használatához.",
    "Disable video" : "Videó kikapcsolása",
    "Share screen" : "Képernyő megosztása",
    "Show your screen" : "Képernyőd megosztása",
    "Stop screensharing" : "Képernyő megosztás befejezése",
    "Unmute audio (m)" : "Hang engedélyezése (m)",
    "Mute audio (m)" : "Audio elnémítása (m)",
    "No audio" : "Nincs hang",
    "Enable video (v)" : "Videó engedélyezése (v)",
    "Disable video (v)" : "Videó kikapcsolása (v)",
    "No Camera" : "Nincs kamera",
    "Screensharing is not supported by your browser." : "A böngésződ nem támogatja a képernyőmegosztást.",
    "Screensharing requires the page to be loaded through HTTPS." : "A képernyőmegosztáshoz HTTPS szükséges.",
    "Screensharing options" : "Képernyő megosztás beállításai",
    "Sharing your screen only works with Firefox version 52 or newer." : "A képernyőmegosztás 52-es és magasabb Firefox verziótól érhető el.",
    "Screensharing extension is required to share your screen." : "Képernyőmegosztó bővítményre van szükség.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Kérjük használj más böngészőt, például Firefox-ot vagy Chrome-ot, a képernyőmegosztáshoz.",
    "An error occurred while starting screensharing." : "Hiba lépett fel a képernyőmegosztás közben.",
    "Enable screensharing" : "Képernyő megosztás engedélyezése",
    "moderator" : "moderátor",
    "Demote from moderator" : "lefokozás moderátorról",
    "Promote to moderator" : "Moderátorrá kinevezés",
    "Remove participant" : "Résztvevő eltávolítása",
    "Add participant …" : "Résztvevő hozzáadása ...",
    "Add to favorites" : "Hozzáadás a kedvencekhez ",
    "Leave conversation" : "Kilépés a beszélgetésből",
    "Delete conversation" : "Beszélgetés törlése",
    "Close" : "Bezár",
    "Show screen" : "Képernyőd mutatása",
    "Access to microphone & camera is only possible with HTTPS" : "A mikrofon és a kamera hozzáférése csak HTTPS-en lehetséges",
    "Please move your setup to HTTPS" : "Kérlek váltsd a konfigurációdat HTTPS-re",
    "Access to microphone & camera was denied" : "A kamera és a mikrofon hozzáférése letiltva",
    "WebRTC is not supported in your browser" : "A böngésződ nem támogatja a WebRTC-t",
    "Error while accessing microphone & camera" : "Hiba a kamera és a mikrofon hozzáférésekor",
    "{participantName}'s screen" : "{participantName} képernyője",
    "Guest's screen" : "Vendég képernyője",
    "Your screen" : "Te képernyőd",
    "(Duration %s)" : "(Időtartam: %s)",
    "You attended a call with {user1}" : "Részt vettél egy hívásban vele: {user1}",
    "_%n guest_::_%n guests_" : ["%n vendég","%n vendég"],
    "You attended a call with {user1} and {user2}" : "Részt vettél egy hívásban velük: {user1}, {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}, {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}, {user4}, {user5}",
    "_%n other_::_%n others_" : ["még %n","még %n"],
    "{actor} invited you to {call}" : "{actor} meghívott ide: {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Meghívtak egy <strong>beszélgető </strong> szobába vagy volt egy <strong>hívásod</strong>",
    "You created the conversation" : "Beszélgetést hoztál létre",
    "You started a call" : "Hívást kezdeményeztél",
    "{actor} joined the call" : "{actor} bekapcsolódott a hívásba",
    "You joined the call" : "Csatlakoztál a híváshoz",
    "You left the call" : "Kiléptél a hívásból",
    "You shared a file which is no longer available" : "Megosztottál egy fájlt, amelyik többé nem elérhető",
    "Talk to %s" : "Beszélgetés vele: %s",
    "_%n other guest_::_%n other guests_" : ["%n további vendég","%n további vendég"],
    ", " : ", ",
    "{user} wants to talk with you" : "{user} beszélni szeretne veled",
    "A group call has started in {call}" : "Csoportos hívás kezdődött itt: {call}",
    "A group call has started" : "Csoportos hívás kezdődött",
    "Invalid date, date format must be YYYY-MM-DD" : "Érvénytelen dátum, a dátum YYYY-MM-DD formátumú kell legyen",
    "This call is password-protected" : "Ez a hívás jelszóval védett",
    "The password is wrong. Try again." : "Hibás jelszó, próbáld újra.",
    "Signaling server" : "Jelző szerver",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Külső jelzőszerver használata is lehetséges nagyobb telepítések esetén. Hagyd üresen a belső szerver használatához.",
    "STUN servers" : "STUN szerverek",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Egy STUN szervert használunk a router mögötti résztvevők IP címének megállapítására.",
    "TURN server" : "TURN kiszolgáló",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "A TURN szervert használjuk a proxyként a tűzfal mögötti felhasználókhoz.",
    "Android app" : "Android alkalmazás",
    "iOS app" : "iOS alkalmazás",
    "(group)" : "(csoport)",
    "and you" : "és te",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …",
    "%s mentioned you in a group conversation: %s" : "%s megemlített téged egy csoportos beszélgetésben: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} megemlített téged egy csoportos beszélgetésben: {call}",
    "%s mentioned you in a group conversation" : "%s megemlített téged egy csoportos beszélgetésben",
    "{user} mentioned you in a group conversation" : "{user} megemlített téged egy csoportos beszélgetésben",
    "A guest mentioned you in a group conversation: %s" : "Egy vendég megemlített téged egy csoportos beszélgetésben: %s",
    "A guest mentioned you in a group conversation: {call}" : "Egy vendég megemlített téged egy csoportos beszélgetésben: {call}",
    "A guest mentioned you in a group conversation" : "Egy vendég megemlített téged egy csoportos beszélgetésben",
    "The TURN server settings are valid." : "A TURN szerver beállítása érvényes."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-5.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/hu.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "SSL tanúsítvány érvényesítése",
    "Delete server" : "Szerver törlése",
    "Add new server" : "Szerver hozzáadása",
    "Saved" : "Elmentve",
    "Shared secret" : "Megosztott titok",
    "TURN server shared secret" : "TURN szerver megosztott titok",
    "UDP and TCP" : "UDP és TCP",
    "UDP only" : "csak UDP",
    "TCP only" : "csak TCP",
    "Test server" : "Szerver tesztelése",
    "TURN server protocols" : "TURN kiszolgáló protokollok",
    "New public conversation" : "Új nyilvános beszélgetés",
    "New group conversation" : "Új csoport beszélgetés",
    "New conversation …" : "Új beszélgetés …",
    "Participants" : "Résztvevők",
    "Chat" : "Csevegés",
    "Talk" : "Beszélgetés",
    "Exit fullscreen (f)" : "Kilépés a teljes képernyős módból (f)",
    "Fullscreen (f)" : "Teljes képernyő (f)",
    "Copy" : "Másol",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "Nyomj ⌘-C-t a másoláshoz.",
    "Press Ctrl-C to copy." : "Nyomj Ctrl-C-t a másoláshoz.",
    "Error while getting the room ID" : "Hiba a szoba ID letöltése közben",
    "Start a conversation" : "Beszélgetés indítása",
    "Share this file with others to discuss" : "Oszd meg ezt a fájlt másokkal a meg beszéléshez",
    "Share" : "Megoszt",
    "Request password" : "Jelszó kérése",
    "Error requesting the password." : "Hiba a jelszó kérésekor.",
    "Please enter the password for this call" : "Kérlek adj meg egy jelszót ehhez a híváshoz",
    "Password required" : "Jelszó szükséges",
    "Password" : "Jelszó",
    "Cancel" : "Mégse",
    "Submit" : "Küldés",
    "Leave call" : "Hívás elhagyása",
    "Join call" : "Csatlakozás híváshoz",
    "Start call" : "Hívás indítása",
    "Share link" : "Megosztás hivatkozással",
    "Change password" : "Jelszó módosítása",
    "Set password" : "Jelszó beállítása",
    "Go to file" : "Ugrás a fájlhoz",
    "Name" : "Név",
    "Conversation name" : "Beszélgetés neve",
    "Rename" : "Átnevezés",
    "Copy link" : "Hivatkozás másolása",
    "Conversation with {name}" : "Beszélgetés vele: {name}",
    "Error occurred while setting password" : "Hiba a jelszó beállításakor",
    "Link copied!" : "Hivatkozás másolva!",
    "You" : "Te",
    "No messages yet, start the conversation!" : "Még nincs üzenet, kezdeményezz beszélgetést!",
    "New message …" : "Új üzenet ...",
    "Send" : "Küld",
    "Guest" : "Vendég",
    "[Unknown user name]" : "[ismeretlen felhasználónév]",
    "Today" : "Ma",
    "Yesterday" : "Tegnap",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "Az üzenet, amit küldeni próbálsz túl hosszú",
    "Error occurred while sending message" : "Hiba az üzenetküldés közben",
    "File to share" : "Fájl megosztása",
    "Error while sharing" : "Hiba megosztás közben",
    "Edit" : "Szerkesztés",
    "Join a conversation or start a new one" : "Csatlakozz egy társalgásba vagy indíts egy újat",
    "Say hi to your friends and colleagues!" : "Üdvözöld a barátaidat és munkatársaidat!",
    "No other people in this call" : "Nincs más ebben a hívásban",
    "Waiting for {participantName} to join the call …" : "Várakozunk, hogy {participantName} csatlakozzon a híváshoz...",
    "Waiting for others to join the call …" : "Várakozunk, hogy mások csatlakozzanak a híváshoz...",
    "You can invite others in the participant tab of the sidebar" : "Az oldalsávon található „közreműködő” fülön lehet másokat meghívni",
    "Share this link to invite others!" : "Oszd meg ezt a linket mások meghívásához!",
    "WebRTC is not supported in your browser :-/" : "A böngésződ nem támogatja a WebRTC-t :-/",
    "Please use a different browser like Firefox or Chrome" : "Kérlek használj másik böngészőt pl Firefoxot vagy Chrome-ot",
    "Waiting for camera and microphone permissions" : "Várakozás kamera és mikrofon engedélyezésre",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Kérlek engedélyezd a kamera és mikrofon elérést az app használatához.",
    "Mute audio" : "Hang némítása",
    "Disable video" : "Videó kikapcsolása",
    "Share screen" : "Képernyő megosztása",
    "Share whole screen" : "Teljes képernyő megosztása",
    "Share a single window" : "Ablak megosztása",
    "Show your screen" : "Képernyőd megosztása",
    "Stop screensharing" : "Képernyő megosztás befejezése",
    "Unmute audio (m)" : "Hang engedélyezése (m)",
    "Mute audio (m)" : "Audio elnémítása (m)",
    "No audio" : "Nincs hang",
    "Enable video (v)" : "Videó engedélyezése (v)",
    "Disable video (v)" : "Videó kikapcsolása (v)",
    "No Camera" : "Nincs kamera",
    "Screensharing is not supported by your browser." : "A böngésződ nem támogatja a képernyőmegosztást.",
    "Screensharing requires the page to be loaded through HTTPS." : "A képernyőmegosztáshoz HTTPS szükséges.",
    "Screensharing options" : "Képernyő megosztás beállításai",
    "Sharing your screen only works with Firefox version 52 or newer." : "A képernyőmegosztás 52-es és magasabb Firefox verziótól érhető el.",
    "Screensharing extension is required to share your screen." : "Képernyőmegosztó bővítményre van szükség.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Kérjük használj más böngészőt, például Firefox-ot vagy Chrome-ot, a képernyőmegosztáshoz.",
    "An error occurred while starting screensharing." : "Hiba lépett fel a képernyőmegosztás közben.",
    "Enable screensharing" : "Képernyő megosztás engedélyezése",
    "moderator" : "moderátor",
    "Demote from moderator" : "lefokozás moderátorról",
    "Promote to moderator" : "Moderátorrá kinevezés",
    "Remove participant" : "Résztvevő eltávolítása",
    "Add participant …" : "Résztvevő hozzáadása ...",
    "Favorited" : "Kedvenc",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add to favorites" : "Hozzáadás a kedvencekhez ",
    "Always notify" : "Mindig értesíts",
    "Never notify" : "Sose értesíts",
    "Leave conversation" : "Kilépés a beszélgetésből",
    "Delete conversation" : "Beszélgetés törlése",
    "Close" : "Bezár",
    "Show screen" : "Képernyőd mutatása",
    "Enable video" : "Videó engedélyezése",
    "Access to microphone & camera is only possible with HTTPS" : "A mikrofon és a kamera hozzáférése csak HTTPS-en lehetséges",
    "Please move your setup to HTTPS" : "Kérlek váltsd a konfigurációdat HTTPS-re",
    "Access to microphone & camera was denied" : "A kamera és a mikrofon hozzáférése letiltva",
    "WebRTC is not supported in your browser" : "A böngésződ nem támogatja a WebRTC-t",
    "Error while accessing microphone & camera" : "Hiba a kamera és a mikrofon hozzáférésekor",
    "{participantName}'s screen" : "{participantName} képernyője",
    "Guest's screen" : "Vendég képernyője",
    "Your screen" : "Te képernyőd",
    "(Duration %s)" : "(Időtartam: %s)",
    "You attended a call with {user1}" : "Részt vettél egy hívásban vele: {user1}",
    "_%n guest_::_%n guests_" : ["%n vendég","%n vendég"],
    "You attended a call with {user1} and {user2}" : "Részt vettél egy hívásban velük: {user1}, {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}, {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}, {user4}, {user5}",
    "_%n other_::_%n others_" : ["még %n","még %n"],
    "{actor} invited you to {call}" : "{actor} meghívott ide: {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Meghívtak egy <strong>beszélgető </strong> szobába vagy volt egy <strong>hívásod</strong>",
    "You created the conversation" : "Beszélgetést hoztál létre",
    "You started a call" : "Hívást kezdeményeztél",
    "{actor} joined the call" : "{actor} bekapcsolódott a hívásba",
    "You joined the call" : "Csatlakoztál a híváshoz",
    "You left the call" : "Kiléptél a hívásból",
    "You allowed guests" : "Vendégeknek is engedélyezted",
    "You disallowed guests" : "Vendégeknek letiltottad",
    "You removed the password" : "Eltávolítottad a jelszót",
    "You joined the conversation" : "Csatlakoztál a beszélgetéshez",
    "You left the conversation" : "Elhagytad a beszélgetést",
    "You shared a file which is no longer available" : "Megosztottál egy fájlt, amelyik többé nem elérhető",
    "Talk to %s" : "Beszélgetés vele: %s",
    "File is not shared, or shared but not with the user" : "A fájl nincs megosztva vagy meg van osztva, de nem a felhasználóval",
    "Password request: %s" : "Jelszó kérés: %s",
    "_%n other guest_::_%n other guests_" : ["%n további vendég","%n további vendég"],
    ", " : ", ",
    "Join »%s«" : "Csatlakozott »%s«",
    "Join now" : "Csatlakozás most",
    "{user} wants to talk with you" : "{user} beszélni szeretne veled",
    "A group call has started in {call}" : "Csoportos hívás kezdődött itt: {call}",
    "A group call has started" : "Csoportos hívás kezdődött",
    "Invalid date, date format must be YYYY-MM-DD" : "Érvénytelen dátum, a dátum YYYY-MM-DD formátumú kell legyen",
    "This call is password-protected" : "Ez a hívás jelszóval védett",
    "The password is wrong. Try again." : "Hibás jelszó, próbáld újra.",
    "Signaling server" : "Jelző szerver",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Külső jelzőszerver használata is lehetséges nagyobb telepítések esetén. Hagyd üresen a belső szerver használatához.",
    "STUN servers" : "STUN szerverek",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Egy STUN szervert használunk a router mögötti résztvevők IP címének megállapítására.",
    "TURN server" : "TURN kiszolgáló",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "A TURN szervert használjuk a proxyként a tűzfal mögötti felhasználókhoz.",
    "Android app" : "Android alkalmazás",
    "iOS app" : "iOS alkalmazás",
    "(group)" : "(csoport)",
    "and you" : "és te",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …",
    "%s mentioned you in a group conversation: %s" : "%s megemlített téged egy csoportos beszélgetésben: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} megemlített téged egy csoportos beszélgetésben: {call}",
    "%s mentioned you in a group conversation" : "%s megemlített téged egy csoportos beszélgetésben",
    "{user} mentioned you in a group conversation" : "{user} megemlített téged egy csoportos beszélgetésben",
    "A guest mentioned you in a group conversation: %s" : "Egy vendég megemlített téged egy csoportos beszélgetésben: %s",
    "A guest mentioned you in a group conversation: {call}" : "Egy vendég megemlített téged egy csoportos beszélgetésben: {call}",
    "A guest mentioned you in a group conversation" : "Egy vendég megemlített téged egy csoportos beszélgetésben",
    "The TURN server settings are valid." : "A TURN szerver beállítása érvényes.",
    "Checking TURN server {server}" : "TURN szerver ellenőrzés {server}"
},
"nplurals=2; plural=(n != 1);");
